.visually-hidden
  position: absolute !important
  width: 1px !important
  height: 1px !important
  padding: 0 !important
  margin: -1px !important
  overflow: hidden !important
  clip: rect(0,0,0,0) !important
  white-space: nowrap !important
  border: 0 !important
  color: var(--color-foreground-primary)
  background: var(--color-background-primary)

:-moz-focusring
  outline: auto
